<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>Batchprocessing</name>
    <message>
        <location filename="../batchprocessing.cpp" line="44"/>
        <source>Error</source>
        <translation>Klaida</translation>
    </message>
    <message>
        <location filename="../batchprocessing.cpp" line="45"/>
        <source>Current kernel doesn&apos;t support selected compression algorithm, please edit the configuration file and select a different algorithm.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="170"/>
        <location filename="../mainwindow.cpp" line="468"/>
        <source>MX Snapshot</source>
        <translation>MX momentinė kopija</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="33"/>
        <source>Optional customization</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="42"/>
        <source>Release date:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="49"/>
        <source>Release codename:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="56"/>
        <source>Live kernel:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="97"/>
        <source>Boot options:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="139"/>
        <source>Release version:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="159"/>
        <source>Change live kernel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="166"/>
        <source>Project name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="195"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Snapshot is a utility that creates a bootable image (ISO) of your working system that you can use for storage or distribution. You can continue working with undemanding applications while it is running.&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="205"/>
        <source>Used space on / (root) and /home partitions:</source>
        <translation>Panaudota vieta / (šaknies) ir /home skaidiniuose:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="215"/>
        <source>Location and ISO name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="242"/>
        <source>Snapshot location:</source>
        <translation>Momentinės kopijos vieta:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="249"/>
        <source>Select a different snapshot directory</source>
        <translation>Pasirinkti kitą momentinės kopijos katalogą</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="260"/>
        <location filename="../mainwindow.cpp" line="343"/>
        <source>Snapshot name:</source>
        <translation>Momentinės kopijos pavadinimas:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="379"/>
        <source>You can also exclude certain directories by ticking the common choices below, or by clicking on the button to directly edit /etc/mx-snapshot-exclude.list.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="436"/>
        <source>exclude network configurations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="439"/>
        <source>Networks</source>
        <translation>Tinklai</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="446"/>
        <source>All of the above</source>
        <translation>Viskas iš aukščiau paminėtų</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="453"/>
        <source>Pictures</source>
        <translation>Paveikslai</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="470"/>
        <source>Desktop</source>
        <translation>Darbalaukis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="487"/>
        <source>Music</source>
        <translation>Muzika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="494"/>
        <source>Downloads</source>
        <translation>Atsiuntimai</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="501"/>
        <source>Videos</source>
        <translation>Vaizdo įrašai</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <source>Documents</source>
        <translation>Dokumentai</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="546"/>
        <source>Type of snapshot:</source>
        <translation>Momentinės kopijos tipas:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="553"/>
        <source>Preserving accounts (for personal backup)</source>
        <translation>Išsaugant paskyras (asmeninei atsarginei kopijai)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="563"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This option will reset &amp;quot;demo&amp;quot; and &amp;quot;root&amp;quot; passwords to the MX Linux defaults and will not copy any personal accounts created.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="566"/>
        <source>Resetting accounts (for distribution to others)</source>
        <translation>Atstatant paskyras (platinimui kitiems žmonėms)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="595"/>
        <source>Edit Exclusion File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="634"/>
        <source>sha512</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="657"/>
        <source>Throttle the I/O input rate by the given percentage.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="663"/>
        <source>I/O throttle:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="670"/>
        <source>Calculate checksums:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="677"/>
        <source>ISO compression scheme:</source>
        <translation>ISO glaudinimo schema:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="684"/>
        <source>Number of CPU cores to use:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="691"/>
        <source>md5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="701"/>
        <source>Options:</source>
        <translation>Parametrai:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="848"/>
        <source>About this application</source>
        <translation>Apie šią programą</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="851"/>
        <source>About...</source>
        <translation>Apie...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="858"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="874"/>
        <source>Quit application</source>
        <translation>Išeiti iš programos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="877"/>
        <source>Cancel</source>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="884"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="916"/>
        <source>Next</source>
        <translation>Tolesnis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="964"/>
        <source>Back</source>
        <translation>Atgal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="981"/>
        <source>Display help </source>
        <translation>Rodyti žinyną</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="984"/>
        <source>Help</source>
        <translation>Žinynas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="991"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="176"/>
        <source>fastest, worst compression</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="176"/>
        <source>fast, worse compression</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="177"/>
        <source>slow, better compression</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="177"/>
        <source>best compromise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="178"/>
        <source>slowest, best compression</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="207"/>
        <source>Free space on %1, where snapshot folder is placed: </source>
        <translation>Laisva vieta %1 skaidinyje, kuriame yra patalpintas momentinės kopijos aplankas: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="210"/>
        <source>The free space should be sufficient to hold the compressed data from / and /home

      If necessary, you can create more available space by removing previous snapshots and saved copies: %1 snapshots are taking up %2 of disk space.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="222"/>
        <location filename="../mainwindow.cpp" line="223"/>
        <source>Installing </source>
        <translation>Įdiegiama </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="311"/>
        <source>Please wait.</source>
        <translation>Prašome palaukti.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="313"/>
        <source>Please wait. Calculating used disk space...</source>
        <translation>Prašome palaukti. Apskaičiuojama panaudota disko vieta...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="327"/>
        <location filename="../mainwindow.cpp" line="354"/>
        <location filename="../mainwindow.cpp" line="385"/>
        <location filename="../mainwindow.cpp" line="389"/>
        <source>Error</source>
        <translation>Klaida</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="328"/>
        <source>Output file %1 already exists. Please use another file name, or delete the existent file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="335"/>
        <source>Settings</source>
        <translation>Nuostatos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="340"/>
        <source>Snapshot will use the following settings:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="342"/>
        <source>- Snapshot directory:</source>
        <translation>- Momentinės kopijos katalogas:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="343"/>
        <source>- Kernel to be used:</source>
        <translation>- Bus naudojamas branduolys:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="355"/>
        <source>Current kernel doesn&apos;t support selected compression algorithm, please edit the configuration file and select a different algorithm.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="362"/>
        <source>Final chance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="364"/>
        <source>Snapshot now has all the information it needs to create an ISO from your running system.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="365"/>
        <source>It will take some time to finish, depending on the size of the installed system and the capacity of your computer.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <source>OK to start?</source>
        <translation>Galima pradėti?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="371"/>
        <source>Shutdown computer when done.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="385"/>
        <source>Could not create working directory. </source>
        <translation>Nepavyko sukurti darbinio katalogo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="389"/>
        <source>Could not create temporary directory. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="424"/>
        <source>Output</source>
        <translation>Išvestis</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="437"/>
        <source>Edit Boot Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="438"/>
        <source>The program will now pause to allow you to edit any files in the work directory. Select Yes to edit the boot menu or select No to bypass this step and continue creating the snapshot.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="451"/>
        <source>Close</source>
        <translation>Užverti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="459"/>
        <source>Select kernel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="544"/>
        <source>About %1</source>
        <translation>Apie %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="546"/>
        <source>Version: </source>
        <translation>Versija: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="547"/>
        <source>Program for creating a live-CD from the running system for MX Linux</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="549"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Autorių teisės (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="551"/>
        <source>%1 License</source>
        <translation>%1 licencija</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="565"/>
        <source>%1 Help</source>
        <translation>%1 žinynas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="570"/>
        <source>Select Snapshot Directory</source>
        <translation>Pasirinkite momentinės kopijos katalogą</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="591"/>
        <source>Confirmation</source>
        <translation>Patvirtinimas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="591"/>
        <source>Are you sure you want to quit the application?</source>
        <translation>Ar tikrai norite išeiti iš programos?</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../batchprocessing.cpp" line="70"/>
        <source>The program will pause the build and open the boot menu in your text editor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Tool used for creating a live-CD from the running system</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="77"/>
        <source>Use CLI only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="79"/>
        <source>Number of CPU cores to be used.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="79"/>
        <location filename="../main.cpp" line="108"/>
        <source>number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="80"/>
        <source>Output directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="80"/>
        <location filename="../main.cpp" line="109"/>
        <source>path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="81"/>
        <source>Output filename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="81"/>
        <source>name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="83"/>
        <source>Name a different kernel to use other than the default running kernel, use format returned by &apos;uname -r&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="85"/>
        <source>Or the full path: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="86"/>
        <source>version, or path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="88"/>
        <source>Compression level options.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="89"/>
        <source>Use quotes: &quot;-Xcompression-level &lt;level&gt;&quot;, or &quot;-Xalgorithm &lt;algorithm&gt;&quot;, or &quot;-Xhc&quot;, see mksquashfs man page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="91"/>
        <source>&quot;option&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="94"/>
        <source>Create a monthly snapshot, add &apos;Month&apos; name in the ISO name, skip used space calculation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="95"/>
        <source>This option sets reset-accounts and compression to defaults, arguments changing those items will be ignored</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="98"/>
        <source>Don&apos;t calculate checksums for resulting ISO file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="100"/>
        <source>Skip calculating free space to see if the resulting ISO will fit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="102"/>
        <source>Option to fix issue with calculating checksums on preempt_rt kernels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="103"/>
        <source>Resetting accounts (for distribution to others)</source>
        <translation>Atstatant paskyras (platinimui kitiems žmonėms)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="104"/>
        <source>Calculate checksums for resulting ISO file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="106"/>
        <source>Throttle the I/O input rate by the given percentage. This can be used to reduce the I/O and CPU consumption of Mksquashfs.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="109"/>
        <source>Work directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="111"/>
        <source>Exclude main folders, valid choices: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="113"/>
        <source>Use the option one time for each item you want to exclude</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="114"/>
        <source>one item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="116"/>
        <source>Compression format, valid choices: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="117"/>
        <source>format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="118"/>
        <source>Shutdown computer when done.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="136"/>
        <location filename="../main.cpp" line="146"/>
        <location filename="../main.cpp" line="187"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="159"/>
        <location filename="../main.cpp" line="199"/>
        <source>version:</source>
        <translation>versija:</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="168"/>
        <location filename="../main.cpp" line="194"/>
        <source>You must run this program with sudo or pkexec.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="178"/>
        <source>MX Snapshot</source>
        <translation>MX momentinė kopija</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="186"/>
        <location filename="../main.cpp" line="193"/>
        <location filename="../main.cpp" line="252"/>
        <location filename="../settings.cpp" line="250"/>
        <location filename="../settings.cpp" line="265"/>
        <location filename="../settings.cpp" line="735"/>
        <location filename="../settings.cpp" line="834"/>
        <source>Error</source>
        <translation>Klaida</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="246"/>
        <location filename="../main.cpp" line="248"/>
        <location filename="../settings.cpp" line="259"/>
        <source>Current kernel doesn&apos;t support Squashfs, cannot continue.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="86"/>
        <source>Could not create working directory. </source>
        <translation>Nepavyko sukurti darbinio katalogo.</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="111"/>
        <source>Could not create temp directory. </source>
        <translation>Nepavyko sukurti laikinojo katalogo.</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="244"/>
        <source>Could not find a usable kernel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="368"/>
        <source>Used space on / (root): </source>
        <translation>Panaudota vieta / (šaknies) skaidinyje: </translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="371"/>
        <source>estimated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="384"/>
        <source>Used space on /home: </source>
        <translation>Panaudota vieta /home skaidinyje: </translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="470"/>
        <source>Free space on %1, where snapshot folder is placed: </source>
        <translation>Laisva vieta %1 skaidinyje, kuriame yra patalpintas momentinės kopijos aplankas: </translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="474"/>
        <source>The free space should be sufficient to hold the compressed data from / and /home

      If necessary, you can create more available space
      by removing previous snapshots and saved copies:
      %1 snapshots are taking up %2 of disk space.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="492"/>
        <source>Desktop</source>
        <translation>Darbalaukis</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="493"/>
        <source>Documents</source>
        <translation>Dokumentai</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="494"/>
        <source>Downloads</source>
        <translation>Atsiuntimai</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="495"/>
        <source>Music</source>
        <translation>Muzika</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="496"/>
        <source>Networks</source>
        <translation>Tinklai</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="497"/>
        <source>Pictures</source>
        <translation>Paveikslai</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="499"/>
        <source>Videos</source>
        <translation>Vaizdo įrašai</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="728"/>
        <location filename="../settings.cpp" line="827"/>
        <source>Output file %1 already exists. Please use another file name, or delete the existent file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>License</source>
        <translation>Licencija</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="71"/>
        <location filename="../about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Keitinių žurnalas</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Užverti</translation>
    </message>
</context>
<context>
    <name>Work</name>
    <message>
        <location filename="../work.cpp" line="80"/>
        <source>Cleaning...</source>
        <translation>Išvaloma...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="91"/>
        <location filename="../work.cpp" line="280"/>
        <source>Done</source>
        <translation>Atlikta</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="102"/>
        <source>Interrupted or failed to complete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="135"/>
        <location filename="../work.cpp" line="238"/>
        <location filename="../work.cpp" line="260"/>
        <location filename="../work.cpp" line="298"/>
        <location filename="../work.cpp" line="410"/>
        <source>Error</source>
        <translation>Klaida</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="136"/>
        <source>There&apos;s not enough free space on your target disk, you need at least %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="139"/>
        <source>You have %1 free space on %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="142"/>
        <source>If you are sure you have enough free space rerun the program with -o/--override-size option</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="167"/>
        <source>Copying the new-iso filesystem...</source>
        <translation>Kopijuojama new-iso failų sistema...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="179"/>
        <source>Could not create temp directory. </source>
        <translation>Nepavyko sukurti laikinojo katalogo.</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="235"/>
        <source>Squashing filesystem...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="239"/>
        <source>Could not create linuxfs file, please check /var/log/%1.log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="257"/>
        <source>Creating CD/DVD image file...</source>
        <translation>Kuriamas CD/DVD atvaizdžio failas...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="261"/>
        <source>Could not create ISO file, please check whether you have enough space on the destination partition.</source>
        <translation>Nepavyko sukurti ISO failo, prašome patikrinti ar paskirties skaidinyje yra pakankamai vietos.</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="267"/>
        <source>Making hybrid iso</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="285"/>
        <source>Success</source>
        <translation>Pavyko</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="286"/>
        <source>MX Snapshot completed sucessfully!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="287"/>
        <source>Snapshot took %1 to finish.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="288"/>
        <source>Thanks for using MX Snapshot, run MX Live USB Maker next!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="295"/>
        <source>Installing </source>
        <translation>Įdiegiama </translation>
    </message>
    <message>
        <location filename="../work.cpp" line="298"/>
        <source>Could not install </source>
        <translation>Nepavyko įdiegti</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="308"/>
        <source>Calculating checksum...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="347"/>
        <source>Building new initrd...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="411"/>
        <source>Could not create working directory. </source>
        <translation>Nepavyko sukurti darbinio katalogo.</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="541"/>
        <source>Calculating total size of excluded files...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="551"/>
        <source>Calculating size of root...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
